pub struct SdfPipelineStore { /* private fields */ }Expand description
Manages cached SDF pipelines and renders SDF commands.
Implementations
Sourceimpl SdfPipelineStore
impl SdfPipelineStore
Sourcepub fn new(gpu: &GpuContext) -> Self
pub fn new(gpu: &GpuContext) -> Self
Create a new SDF pipeline store.
Sourcepub fn new_headless(device: &Device, format: TextureFormat) -> Self
pub fn new_headless(device: &Device, format: TextureFormat) -> Self
Create for headless testing (no surface required).
Sourcepub fn prepare(&self, queue: &Queue, camera: &Camera2D, time: f32)
pub fn prepare(&self, queue: &Queue, camera: &Camera2D, time: f32)
Update the camera and time uniforms. Call once per frame before rendering.
Sourcepub fn set_time(&self, queue: &Queue, time: f32)
pub fn set_time(&self, queue: &Queue, time: f32)
Update the time uniform. Call once per frame before rendering.
Sourcepub fn get_or_create_pipeline(
&mut self,
device: &Device,
sdf_expr: &str,
fill: &SdfFill,
) -> u64
pub fn get_or_create_pipeline( &mut self, device: &Device, sdf_expr: &str, fill: &SdfFill, ) -> u64
Get or create the render pipeline for the given SDF expression + fill. Returns a reference to the cached pipeline.
Sourcepub fn camera_bind_group_layout(&self) -> &BindGroupLayout
pub fn camera_bind_group_layout(&self) -> &BindGroupLayout
Return the camera bind group layout for sharing with the sprite pipeline.
Sourcepub fn render(
&mut self,
device: &Device,
encoder: &mut CommandEncoder,
target: &TextureView,
commands: &[SdfCommand],
clear_color: Option<Color>,
)
pub fn render( &mut self, device: &Device, encoder: &mut CommandEncoder, target: &TextureView, commands: &[SdfCommand], clear_color: Option<Color>, )
Render a sorted slice of SDF commands.
Commands should be pre-sorted by layer. Within each pipeline key, instances are batched into a single instanced draw call.
Call prepare() once per frame before calling render().
clear_color: Some(color) -> LoadOp::Clear, None -> LoadOp::Load.
Sourcepub fn pipeline_count(&self) -> usize
pub fn pipeline_count(&self) -> usize
Number of cached pipelines (useful for diagnostics).