Module target_ops

Module target_ops 

Structs

TargetState
State for all live render targets and the currently active one.
target_ext
An extension for use with the Deno JS runtime. To use it, provide it as an argument when instantiating your runtime: